@@ -1,7 +1,8 @@
 def __bootstrap__():
     global __bootstrap__, __loader__, __file__
-    import sys, pkg_resources, imp
+    import sys, pkg_resources
+    from importlib.machinery import ExtensionFileLoader
     __file__ = pkg_resources.resource_filename(__name__, '_gdal.cp38-win_amd64.pyd')
     __loader__ = None; del __bootstrap__, __loader__
-    imp.load_dynamic(__name__,__file__)
+    ExtensionFileLoader(__name__,__file__).load_module()
 __bootstrap__()
